Popup class

Annotations
  • @Entity.new(tableName: 'popups')
  • @TypeConverters.new([ComponentListConverter])

Constructors

Popup({required String id, required String title, required String popupToken, required int priority, required String status, required String interaction, required String popupBackground, required String popupTime, required String createdAt, required List<List<Component>> components})
Popup.fromJson(Map<String, dynamic> json)
factory

Properties

components List<List<Component>>
final
createdAt String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
interaction String
final
popupBackground String
final
popupTime String
final
popupToken String
final
priority int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
final
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited