ApiService class
Constructors
- ApiService(String apiUrl, String clientApiUrl, AppDatabase database, String? appId)
Properties
- apiUrl → String
-
final
- appId → String?
-
final
- clientApiUrl → String
-
final
- database → AppDatabase
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storageHelper → StorageHelper
-
final
Methods
-
closePopUp(
String popUpId, String userName, String popUpToken, String userId) → Future< void> -
commentPopUp(
String popUpId, String userName, String popUpToken, String userId, String commentValue) → Future< void> -
connectClientApi(
String memberId, String userName, Map< String, dynamic> metadata) → Future<void> -
getVersion(
String memberId, String userName, Map< String, dynamic> metadata) → Future<void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
postReact(
String popUpId, String userName, String popUpToken, String userId, String interaction) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited