PopupWidget class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- isOverlayActive ↔ bool
-
getter/setter pair
Static Methods
-
showPopup(
String? popupBackgroundImage, String? popupBackground, String title, int titleFontSize, String apiUrl, String clientApiUrl, String titleFontFamily, String titleColor, String titleFontWeight, String titleVisibility, List< Map< items, List<String, dynamic> >String> emojiList, String interaction, String popUpId, String userName, String popUpToken, String userId, List components, String videoLink, int? popupTime, int? primaryPeriority, BuildContext context, AppDatabase database, String appId) → void